==> owncloud-8.1.0p2.tgz: owncloud/core/l10n/cy_GB.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Settings" : "Gosodiadau",
    "Saving..." : "Yn cadw...",
    "No" : "Na",
    "Yes" : "Ie",
    "Choose" : "Dewisiwch",
    "Ok" : "Iawn",
    "Cancel" : "Diddymu",
    "Shared" : "Rhannwyd",
    "Share" : "Rhannu",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Error while changing permissions" : "Gwall wrth newid caniatâd",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "Password protect" : "Diogelu cyfrinair",
    "Password" : "Cyfrinair",
    "Email link to person" : "E-bostio dolen at berson",
    "Send" : "Anfon",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "group" : "grŵp",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Shared in {item} with {user}" : "Rhannwyd yn {item} â {user}",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "access control" : "rheolaeth mynediad",
    "create" : "creu",
    "delete" : "dileu",
    "Password protected" : "Diogelwyd â chyfrinair",
    "Error unsetting expiration date" : "Gwall wrth ddad-osod dyddiad dod i ben",
    "Error setting expiration date" : "Gwall wrth osod dyddiad dod i ben",
    "Sending ..." : "Yn anfon ...",
    "Email sent" : "Anfonwyd yr e-bost",
    "Warning" : "Rhybudd",
    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
    "Delete" : "Dileu",
    "Add" : "Ychwanegu",
    "The update was successful. Redirecting you to ownCloud now." : "Roedd y diweddariad yn llwyddiannus. Cewch eich ailgyfeirio i ownCloud nawr.",
    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
    "New password" : "Cyfrinair newydd",
    "Reset password" : "Ailosod cyfrinair",
    "Personal" : "Personol",
    "Users" : "Defnyddwyr",
    "Apps" : "Pecynnau",
    "Admin" : "Gweinyddu",
    "Help" : "Cymorth",
    "Access forbidden" : "Mynediad wedi'i wahardd",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Mwy na thebyg fod modd cyrraedd eich cyfeiriadur data a ffeilau o'r rhyngrwyd oherwydd nid yw'r ffeil .htaccess yn gweithio. ",
    "Create an <strong>admin account</strong>" : "Crewch <strong>gyfrif gweinyddol</strong>",
    "Username" : "Enw defnyddiwr",
    "Data folder" : "Plygell data",
    "Configure the database" : "Cyflunio'r gronfa ddata",
    "Database user" : "Defnyddiwr cronfa ddata",
    "Database password" : "Cyfrinair cronfa ddata",
    "Database name" : "Enw cronfa ddata",
    "Database tablespace" : "Tablespace cronfa ddata",
    "Database host" : "Gwesteiwr cronfa ddata",
    "Finish setup" : "Gorffen sefydlu",
    "Log out" : "Allgofnodi",
    "Search" : "Chwilio",
    "remember" : "cofio",
    "Log in" : "Mewngofnodi",
    "Alternative Logins" : "Mewngofnodiadau Amgen"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/cy_GB.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sun." : "Sul.",
    "Mon." : "Llun.",
    "Tue." : "Maw.",
    "Wed." : "Mer.",
    "Thu." : "Iau.",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Jan." : "Ion.",
    "Feb." : "Chwe.",
    "Mar." : "Maw.",
    "Apr." : "Ebr.",
    "May." : "Mai.",
    "Jun." : "Meh.",
    "Jul." : "Gor.",
    "Aug." : "Aws.",
    "Sep." : "Med.",
    "Oct." : "Hyd.",
    "Nov." : "Tach.",
    "Dec." : "Rhag.",
    "Settings" : "Gosodiadau",
    "Saving..." : "Yn cadw...",
    "seconds ago" : "eiliad yn ôl",
    "No" : "Na",
    "Yes" : "Ie",
    "Choose" : "Dewisiwch",
    "Ok" : "Iawn",
    "Cancel" : "Diddymu",
    "Shared" : "Rhannwyd",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Error while changing permissions" : "Gwall wrth newid caniatâd",
    "Error setting expiration date" : "Gwall wrth osod dyddiad dod i ben",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "Sending ..." : "Yn anfon ...",
    "Email sent" : "Anfonwyd yr e-bost",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Password protect" : "Diogelu cyfrinair",
    "Password" : "Cyfrinair",
    "Email link to person" : "E-bostio dolen at berson",
    "Send" : "Anfon",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "Shared in {item} with {user}" : "Rhannwyd yn {item} â {user}",
    "group" : "grŵp",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "create" : "creu",
    "delete" : "dileu",
    "access control" : "rheolaeth mynediad",
    "Share" : "Rhannu",
    "Warning" : "Rhybudd",
    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
    "Delete" : "Dileu",
    "Add" : "Ychwanegu",
    "The update was successful. Redirecting you to ownCloud now." : "Roedd y diweddariad yn llwyddiannus. Cewch eich ailgyfeirio i ownCloud nawr.",
    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
    "New password" : "Cyfrinair newydd",
    "Reset password" : "Ailosod cyfrinair",
    "Personal" : "Personol",
    "Users" : "Defnyddwyr",
    "Apps" : "Pecynnau",
    "Admin" : "Gweinyddu",
    "Help" : "Cymorth",
    "Access forbidden" : "Mynediad wedi'i wahardd",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Mwy na thebyg fod modd cyrraedd eich cyfeiriadur data a ffeilau o'r rhyngrwyd oherwydd nid yw'r ffeil .htaccess yn gweithio. ",
    "Create an <strong>admin account</strong>" : "Crewch <strong>gyfrif gweinyddol</strong>",
    "Username" : "Enw defnyddiwr",
    "Data folder" : "Plygell data",
    "Configure the database" : "Cyflunio'r gronfa ddata",
    "Database user" : "Defnyddiwr cronfa ddata",
    "Database password" : "Cyfrinair cronfa ddata",
    "Database name" : "Enw cronfa ddata",
    "Database tablespace" : "Tablespace cronfa ddata",
    "Database host" : "Gwesteiwr cronfa ddata",
    "Finish setup" : "Gorffen sefydlu",
    "Log out" : "Allgofnodi",
    "Search" : "Chwilio",
    "Log in" : "Mewngofnodi",
    "remember" : "cofio",
    "Alternative Logins" : "Mewngofnodiadau Amgen"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
